#
# spec file for package editorconfig-checker
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name ec

Name:           editorconfig-checker
Version:        3.2.0
Release:        1.1
Summary:        Tool to verify that your files are in harmony with your .editorconfig
License:        MIT
URL:            https://github.com/editorconfig-checker/editorconfig-checker
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh
Provides:       ec = %{version}

%description
This is a tool to check if your files consider your .editorconfig rules. Most
tools—like linters, for example—only test one filetype and need an extra
configuration. This tool only needs your .editorconfig to check all files.

If you don't know about editorconfig already you can read about it here:
editorconfig.org.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.version=v%{version}" \
   -o bin/%{executable_name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

%check
%{buildroot}/%{_bindir}/%{executable_name} -version | grep v%{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%changelog
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.2.0:
  * chore(main): release 3.2.0 (#426)
  * feat: add support for env var NO_COLOR (#429)
  * chore(deps): bump anchore/sbom-action from 0.17.9 to 0.18.0
    (#431)
  * chore: replace token bound to a human by one bound to a bot
    (#422)
  * fix: improve default excludes (#427)
  * feat: only output "0 errors found" when verbose output is
    enabled (#423)
  * chore: replace DOCKER_USERNAME secret by a variable (#421)
  * chore: remove VERSION file (#419)
  * chore: remove old build-binary-in-docker Dockerfile (#418)
  * chore(deps): bump wagoid/commitlint-github-action from 6.2.0 to
    6.2.1 (#424)
* Mon Jan 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.1.2:
  * chore(main): release 3.1.2 (#417)
  * fix: provide both .tar.gz as well as .zip archives (#416)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.7 to
    0.5.8 (#401)
  * chore: use go1.23(.4) to build and release (#414)
* Thu Jan  9 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.1.1:
  * chore(main): release 3.1.1 (#412)
  * fix: dockerfile expected binary at /, not /usr/bin/ #410 (#411)
* Wed Jan  8 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.1.0:
  * chore(main): release 3.1.0 (#408)
  * chore(deps): bump anchore/sbom-action from 0.17.4 to 0.17.9
    (#407)
  * chore(deps): bump github.com/gabriel-vasile/mimetype from 1.4.7
    to 1.4.8 (#406)
  * fix: actually use the correct end marker (#405)
  * fix: this release-please marker (#403)
  * ci: build artifacts with GoReleaser and use Release Please
    (#385)
  * chore(deps): bump wagoid/commitlint-github-action from 6.1.2 to
    6.2.0 (#400)
  * chore(deps): bump github.com/gabriel-vasile/mimetype from 1.4.6
    to 1.4.7 (#398)
  * chore(deps): bump golang.org/x/text from 0.20.0 to 0.21.0
    (#399)
  * chore(deps): bump codecov/codecov-action from 4 to 5 (#396)
  * chore(deps): bump golang.org/x/text from 0.19.0 to 0.20.0
    (#395)
  * refactor: replace Logger.LogMessage by storing an io.Writer
    (#380)
  * chore(deps): bump github.com/gabriel-vasile/mimetype from 1.4.5
    to 1.4.6 (#393)
  * docs: fix Hits-of-Code badge (#391)
  * chore: rename our own .ecrc to the new name (#392)
  * chore: pre-commit v2 (#384)
  * chore: add a pre-commit config (#381)
  * fix: add `.ecrc` deprecation warning (#389)
  * fix: typo in config, `SpacesAftertabs` => `SpacesAfterTabs`
    (#386)
  * chore(deps): bump golang.org/x/text from 0.18.0 to 0.19.0
    (#387)
  * chore: load codecov token from secrets (#382)
  * docs: add CONTRIBUTING.md and MAINTAINERS.md (#378)
  * refactor: output FormatErrors (#377)
  * feat: support `.editorconfig-checker.json` config (#375)
  * docs: try to explain excludes better for #370 (#372)
  * chore: docker `FROM…as` to `FROM…AS` (#376)
  * feat: provide Codeclimate compatible report fromat (#367)
  * chore(deps): bump golang.org/x/text from 0.17.0 to 0.18.0
    (#369)
  * chore(deps): bump wagoid/commitlint-github-action from 6.1.1 to
    6.1.2 (#368)
  * feat: consolidate adjacent error messages (#360)
  * feat: editorconfig-checker-disable-next-line (#363)
  * feat: add zip version when compressing all binaries (#321)
    (#362)
  * chore(deps): bump wagoid/commitlint-github-action from 6.0.2 to
    6.1.1 (#361)
  * chore(deps): bump golang.org/x/text from 0.16.0 to 0.17.0
    (#358)
  * chore(deps): bump wagoid/commitlint-github-action from 6.0.1 to
    6.0.2 (#357)
  * chore(deps): bump github.com/gabriel-vasile/mimetype from 1.4.4
    to 1.4.5 (#356)
* Mon Dec 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.3:
  * chore(release): v3.0.3
  * ci: publish docker image (#355)
  * Revert "fix: check if multiple newlines are at EOF (#350)" (#354)
  * chore(release): v3.0.2
  * build: remove openbsd/mips64
  * fix: check if multiple newlines are at EOF (#350)
  * ci: run docker login and publish on main and on tags creation (#344)
  * ci: remove changelog gen (#352)
  * chore(deps): bump docker/build-push-action from 5 to 6 (#349)
* Mon Dec 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package editorconfig-checker: a tool to verify that your
  files are in harmony with your .editorconfig
